@@ -1,18 +1,18 @@
 /*
  * content detection routines
- * Copyright (c)2007-2009 Daniel Mealha Cabrita
+ * Copyright (c)2007-2010 Daniel Mealha Cabrita
  *
  * Released under the GNU General Public License v2 or later version.
  */
 
 #ifndef CDETECT_H
 
-enum t_content_type {
+enum t_cd_content_type {
 	CD_TEXT_HTML,
 	CD_UNKNOWN
 };
 
-enum t_content_type detect_content_type (const char *content);
+enum t_cd_content_type detect_content_type (const char *content);
 
 #define CDETECT_H
 #endif
