@@ -2,7 +2,7 @@
  * Part of ziproxy package.
  *
  * Copyright (c)2003-2004 Juraj Variny<variny@naex.sk>
- * Copyright (c)2005-2009 Daniel Mealha Cabrita
+ * Copyright (c)2005-2010 Daniel Mealha Cabrita
  *
  * Released subject to GNU General Public License v2 or later version.
  *
@@ -27,10 +27,11 @@
 #define fastputc(x,y) putc(x,y)
 #endif
 
+#include "globaldefs.h"
 
-int gzip_stream_stream (FILE *source, FILE *dest, int level, int *inlen, int *outlen, int de_chunk);
-int gunzip_stream_stream (FILE *source, FILE *dest, int *inlen, int *outlen, int de_chunk, int max_ratio, int min_eval);
-int gzip_memory_stream (const char *source, FILE *dest, int level, int inlen, int *outlen);
+int gzip_stream_stream (FILE *source, FILE *dest, int level, ZP_DATASIZE_TYPE *inlen, ZP_DATASIZE_TYPE *outlen, int de_chunk);
+int gunzip_stream_stream (FILE *source, FILE *dest, ZP_DATASIZE_TYPE *inlen, ZP_DATASIZE_TYPE *outlen, int de_chunk, int max_ratio, ZP_DATASIZE_TYPE min_eval);
+int gzip_memory_stream (const char *source, FILE *dest, int level, ZP_DATASIZE_TYPE inlen, ZP_DATASIZE_TYPE *outlen);
 
 #endif //SRC_ZPIPE_H
 
