@@ -1,6 +1,6 @@
 /* 
  * Quick'n'Dirty config-file parser (2007-10-16)
- * Copyright (c)2007-2009 Daniel Mealha Cabrita
+ * Copyright (c)2007-2010 Daniel Mealha Cabrita
  * Licensed under GNU GPL v2 or later version
  */
 
@@ -271,7 +271,7 @@ int check_conf_key (const char *src, int src_len, const char *conf_key)
  * returns: string with value, or NULL if not found
  * NOTE: the returned pointer, if != NULL, should be freed manually
  */
-char *get_single_val (t_qp_configfile *conf_handler, const char *conf_key)
+char *get_single_val (t_qp_configfile *conf_handler, const char *conf_key, t_qp_parm_status parm_status)
 {
 	char *readpos;
 	int linelen;
@@ -286,6 +286,11 @@ char *get_single_val (t_qp_configfile *conf_handler, const char *conf_key)
 	readpos = conf_handler->filedata;
 	while ((linelen = get_line_len (readpos)) != 0) {
 		if (check_conf_key (readpos, linelen, conf_key) == 1) {
+			if (parm_status == QP_PARM_STATUS_OBSOLETE)
+				log_error (conf_handler, conf_key, QP_ERROR_OBSOLETE);
+			if (parm_status == QP_PARM_STATUS_NOT_SUPPORTED)
+				log_error (conf_handler, conf_key, QP_ERROR_NOT_SUPPORTED);
+
 			if (ret_data != NULL)
 				log_error (conf_handler, conf_key, QP_ERROR_DUPLICATED);
 			
@@ -349,7 +354,7 @@ char *get_single_val_typed_adjusted (t_qp_configfile *conf_handler, const char *
 {
 	char *ret_data;
 	
-	if ((ret_data = get_single_val (conf_handler, conf_key)) != NULL) {
+	if ((ret_data = get_single_val (conf_handler, conf_key, QP_PARM_STATUS_VALID)) != NULL) {
 		if (check_datatype_sanity (conf_handler, conf_key, ret_data, datatype)) {
 			if ((datatype == QP_DATATYPE_STRING) || (datatype == QP_DATATYPE_ARRAY))
 				remove_quotes (ret_data, datatype);
@@ -494,7 +499,7 @@ char *remove_quotes (char *src, t_qp_datatype datatype)
 		return (NULL);
 	}
 
-	strncpy (src, src + 1, srclen - 2);
+	memmove (src, src + 1, (srclen - 2) * sizeof (char));
 	*(src + (srclen - 2)) = '\0';
 	return (src);
 }
@@ -852,6 +857,22 @@ int qp_get_array_size (t_qp_configfile *conf_handler, const char *conf_key)
 	return (array_size);
 }
 
+/* used to warn uses that a parameter has special status
+   DO NOT use for parameters already declared with qp_getconf_*,
+   since those are already considered QP_PARM_STATUS_VALID */
+void qp_set_parameter_status (t_qp_configfile *conf_handler, t_qp_parm_status parm_status, const char *conf_key)
+{
+	get_single_val (conf_handler, conf_key, parm_status);
+}
+
+/* returns !=0 is parameter exists in config file */
+int qp_check_parameter_existence (t_qp_configfile *conf_handler, const char *conf_key)
+{
+	if (get_single_val (conf_handler, conf_key, QP_PARM_STATUS_VALID) != NULL)
+		return (1);
+	return (0);
+}
+
 /* add to the errorlist pool options which were not requested (using qp_getconf_* funtions)
  * up to the point this function is called
  * use this if you do _not_ want the parser to simply ignore unrecognized options */
