@@ -1,6 +1,6 @@
 /* 
  * Ziproxy Log Tool
- * Copyright (c)2006-2009 Daniel Mealha Cabrita
+ * Copyright (c)2006-2010 Daniel Mealha Cabrita
  * Released subject to GNU General Public License v2 or later version (see documentation)
  */
 
@@ -10,6 +10,7 @@
 #include <getopt.h>
 #include <stdarg.h>
 #include <stdlib.h>
+#include "../globaldefs.h"
 
 #define LINE_BUFFER 4096
 #define HOSTNAME_BUFFER 256
@@ -63,8 +64,10 @@ int string_fingerprint (const char *given_string)
 	this_char = (int) *given_string;
 	while (this_char != 0) {
 		fingerprint += this_char;
-		fingerprint ^= (this_char) << 16;
-		fingerprint ^= fingerprint << 8;
+		fingerprint ^= (this_char) << 15;
+		fingerprint ^= fingerprint << 7;
+		fingerprint ^= fingerprint >> 24;
+
 		this_char = (int) *given_string;
 		given_string++;
 	}
@@ -159,10 +162,10 @@ int stats_matrix_add_into (t_stats_matrix *stats_matrix, long long int bytes_in,
 
 	/* checks in cache, first */
 	counter = 0;
-	while (counter < HOSTNAME_CACHE_ENTRIES) {
-		if (stats_matrix->hostname_cache.host_name_fingerprint [counter] == host_name_fingerprint) {
-			if (stats_matrix->hostname_cache.entry_position_in_table [counter] >= 0) {
-				if (! fast_strcmp (table[stats_matrix->hostname_cache.entry_position_in_table [counter]].host_name, host_name)) {
+	while (LIKELY(counter < HOSTNAME_CACHE_ENTRIES)) {
+		if (UNLIKELY(stats_matrix->hostname_cache.host_name_fingerprint [counter] == host_name_fingerprint)) {
+			if (LIKELY(stats_matrix->hostname_cache.entry_position_in_table [counter] >= 0)) {
+				if (LIKELY(! fast_strcmp (table[stats_matrix->hostname_cache.entry_position_in_table [counter]].host_name, host_name))) {
 					pos_in_matrix = stats_matrix->hostname_cache.entry_position_in_table [counter];
 					found_in_cache = 1;
 					counter = HOSTNAME_CACHE_ENTRIES; /* ends loop */				
@@ -171,13 +174,13 @@ int stats_matrix_add_into (t_stats_matrix *stats_matrix, long long int bytes_in,
 		}
 		counter++;
 	}
-	
+
 	/* if not found in cache, search the whole table */
-	if (pos_in_matrix < 0) {
+	if (UNLIKELY(pos_in_matrix < 0)) {
 		counter = 0;
-		while (counter < used_entries) {
-			if (fingerprints_table[counter] == host_name_fingerprint) {
-				if (! fast_strcmp (table[counter].host_name, host_name)) {
+		while (LIKELY(counter < used_entries)) {
+			if (UNLIKELY(fingerprints_table[counter] == host_name_fingerprint)) {
+				if (LIKELY(! fast_strcmp (table[counter].host_name, host_name))) {
 					pos_in_matrix = counter;
 					counter = used_entries; /* ends loop */
 				}
@@ -187,7 +190,7 @@ int stats_matrix_add_into (t_stats_matrix *stats_matrix, long long int bytes_in,
 	}
 	
 	/* create host entry, if it does not exist */
-	if (pos_in_matrix < 0) {
+	if (UNLIKELY(pos_in_matrix < 0)) {
 		pos_in_matrix = stats_matrix_alloc_entry (stats_matrix);
 		if (pos_in_matrix < 0) // realloc error
 			return (-1);
@@ -276,19 +279,19 @@ int pick_element (const char *in_buf, char *out_buf, int element)
 	while (element) {
 		/* skip characters */
 		/* != '\0' && != ' ' */
-		while ((unsigned) *count > (unsigned) ' ')
+		while (LIKELY((unsigned) *count > (unsigned) ' '))
 			count++;
 		
 		element--;
 		
 		/* skip spaces */
-		while (*count == ' ')
+		while (LIKELY(*count == ' '))
 			count++;
 	}
 	
 	/* determine element size */
 	/* != '\0' && != ' ' */
-	while ((unsigned) *(count + element_len) > (unsigned) ' ')
+	while (LIKELY((unsigned) *(count + element_len) > (unsigned) ' '))
 		element_len++;
 
 	// strncpy (out_buf, count, element_len);
@@ -531,7 +534,7 @@ void process_command_line_arguments (t_goptions *goptions, int argc, char **argv
 				break;
 			case 'h':
 				fprintf (stderr, "Ziproxy Log Tool 1.1\n"
-						"Copyright (c)2006-2009 Daniel Mealha Cabrita\n"
+						"Copyright (c)2006-2010 Daniel Mealha Cabrita\n"
 						"Licensed under GNU GPL v2 or later version. See documentation for details.\n\n"
 						"Usage: ziproxylogtool <-m <mode>> [-i <filename>] [-o <filename>] [-h] ... [other options]\n\n"
 						"GENERAL OPTIONS\n\n"
