@@ -1,7 +1,7 @@
 /* txtfiletools.h
  * Part of ziproxy package
  *
- * Copyright (c)2005-2009 Daniel Mealha Cabrita
+ * Copyright (c)2005-2010 Daniel Mealha Cabrita
  *
  * Released subject to GNU General Public License v2 or later version.
  *
@@ -17,6 +17,8 @@ extern char *load_textfile_to_memory (const char *given_filename);
 extern int get_line_len_char (const char *src, const char which_char);
 extern int get_line_len (const char *src);
 extern void remove_junk_data (const char *src, char *dst);
+extern int file_exists (const char *given_filename);
+extern int dump_string_to_textfile (const char *given_filename, const char *given_string);
 
 #endif
 
