@@ -2,7 +2,7 @@
  * Part of ziproxy package.
  *
  * Copyright (c)2002-2004 Juraj Variny<variny@naex.sk>
- * Copyright (c)2005-2009 Daniel Mealha Cabrita
+ * Copyright (c)2005-2010 Daniel Mealha Cabrita
  *
  * Released subject to GNU General Public License v2 or later version.
  *
@@ -16,7 +16,9 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
-int ziproxy (const char *client_addr, struct sockaddr_in *socket_host);
+#include "globaldefs.h"
+
+int ziproxy (const char *client_addr, struct sockaddr_in *socket_host, SOCKET sock_child_out);
 
 #endif //SRC_ZIPROXY_H
 
